#
# spec file for package webdot
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cgibindir  %{apache_serverroot}/cgi-bin
%define htmldir    %{apache_serverroot}/htdocs
%define httpdconf  %(rpm -ql apache2 | grep '/uid\\\.conf$')
%define cachedir   %{_localstatedir}/cache/webdot
%define tclsh83bin %(rpm -ql tcl | grep '/tclsh$')
Name:           webdot
Version:        2.30
Release:        4.11
Summary:        A CGI graph server script that uses tcldot from graphviz
License:        BSD-3-Clause
Group:          Productivity/Graphics/Visualization/Graph
URL:            https://www.graphviz.org/
Source:         http://www.graphviz.org/pub/graphviz/stable/SOURCES//%{name}-%{version}.tar.gz
Patch1:         rpm-specifics.diff
BuildRequires:  apache-rpm-macros
BuildRequires:  apache2-devel
BuildRequires:  ghostscript-fonts-std
BuildRequires:  ghostscript-library
BuildRequires:  graphviz
BuildRequires:  libapr-util1-devel
BuildRequires:  perl-GD
BuildRequires:  tcl-devel
Requires:       ghostscript
Requires:       http_daemon
# FIXME: use proper Requires(pre/post/preun/...)
PreReq:         filesystem
PreReq:         fileutils
BuildArch:      noarch

%description
A cgi-bin program that produces clickable graphs in web pages when
provided with an href to a .dot file.  Uses Tcldot from the graphviz
rpm. By default, only requests from localhost are served.

%prep
%setup -q
%patch1 -p1

%build

%install
make install						\
    DESTDIR=%{buildroot}				\
    BUILD_DIR=.						\
    CGI-BIN_DIR=%{cgibindir}				\
    HTML_DIR=%{htmldir}					\
    CACHE_DIR=%{_localstatedir}/cache				\
    HTTPD-USER-GROUP=%{apache_user}:%apache_group		\
    TCLSH_EXECUTABLE=%{tclsh83bin}			\
    GS=%(which gs)					\
    PS2EPSI=%(which ps2epsi)
rm -f %{buildroot}%{cgibindir}/webdot.tcl

%files
%license COPYING
%doc README AUTHORS CHANGES
%attr(755,root,root) %{cgibindir}/webdot
%attr(-,root,root) %{htmldir}/webdot/
%attr(700,%{apache_user},%{apache_group}) %{cachedir}/

%changelog
* Tue Dec  1 2020 pgajdos@suse.com
- use system apache rpm macros
- run spec-cleaner
* Fri Dec  6 2013 pth@suse.de
- Update to 2.30 which alignes webdot with graphiz 2.30.
- Change URL to the current one.
* Mon Dec 24 2012 p.drouand@gmail.com
- Update to 2.26 version:
  * add support for "truecolor=1" in graphs
  * aligned with graphviz-2.26
* Fri Sep 11 2009 aj@suse.de
- Remove blt and other unneeded requirements from buildrequires.
* Wed Apr 18 2007 dmueller@suse.de
- remove freetype from buildrequires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Nov 29 2005 ro@suse.de
- added freetype2 to nfb
* Tue Nov 29 2005 ro@suse.de
- added fontconfig to nfb
* Mon Aug 29 2005 agruen@suse.de
- Update to version 2.6: align with graphviz; fixes to graphquest.
* Mon Feb 21 2005 agruen@suse.de
- Update to version 2.2.
* Sun Apr 18 2004 ro@suse.de
- build with apache2
* Mon Aug 25 2003 pthomas@suse.de
- Move actions from %%post to %%install (fixes #29061)
* Mon May 19 2003 mmj@suse.de
- Remove CVS dirs
* Tue Aug 20 2002 mmj@suse.de
- Correct PreReq
* Tue Jul  2 2002 garloff@suse.de
- Update to webdot-1.8.5:
  * avoid Moz1.0 crash with SVG embedding using <iframe> trick
  * update newarrows.dot demo graph
  * allow encoded QUERY_STRINGS a la %%3f (?)
* Wed Jun 12 2002 ro@suse.de
- fix build independent of apache version
* Wed May  8 2002 garloff@suse.de
- Update to 1.8.4:
  * SVG improvements
  * fix 127.0.0.1 problem
  * Use PostScript2 and use for PDF generation
  * Improve error handling
* Sun Feb 17 2002 ro@suse.de
- use apxs to get server-root
* Fri Feb  1 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Mon Jan 28 2002 garloff@suse.de
- Update to 1.7.16:
  * SVG and SVGZ format support
  * twopi layout support
  * more and better demo graphs
- bzip2 sources
* Wed Oct 24 2001 ro@suse.de
- apache-group is now specified as #-1 in httpd.conf
  can't use this here, so use hardcoded nogroup
* Thu Jul 26 2001 kukuk@suse.de
- Fix needed for build
* Sat Dec 16 2000 garloff@suse.de
- Update to 1.7.4:
  * rework to support spec of layout engine in the URL
  * various updates to demo and tutorial web pages
* Mon Dec 11 2000 garloff@suse.de
- Create webdot-1.7.3 (split off from graphviz)
